@@ -49,8 +49,9 @@ class CliIndicatorSerialization(threat_updates.ThreatUpdateSerialization):
     def te_threat_updates_fields(cls):
         return SimpleDescriptorRollup.te_threat_updates_fields()
 
+    # ToDo this violates Liskov but is already used in Prod and will require a larger refactor
     @classmethod
-    def store(
+    def store(  # type: ignore
         cls, state_dir: pathlib.Path, contents: t.Iterable["CliIndicatorSerialization"]
     ) -> t.List[pathlib.Path]:
         # Stores in multiple files split by indicator type
@@ -61,15 +62,14 @@ class CliIndicatorSerialization(threat_updates.ThreatUpdateSerialization):
         for threat_type, items in row_by_type.items():
             path = state_dir / f"simple.{threat_type}{Dataset.EXTENSION}"
             ret.append(path)
-            with path.open("w") as f:
+            with path.open("w", encoding="utf-8", newline="") as f:
                 writer = csv.writer(f)
-                writer.writerows(item.as_csv_row() for item in items)
+                for item in items:
+                    writer.writerow(item.as_csv_row())
         return ret
 
     @classmethod
-    def load(
-        cls, state_dir: pathlib.Path
-    ) -> t.List["threat_updates.ThreatUpdateSerialization"]:
+    def load(cls, state_dir: pathlib.Path) -> t.Iterable["CliIndicatorSerialization"]:
         """Load this serialization from the state directory"""
         ret = []
         pattern = r"simple\.([^.]+)" + re.escape(Dataset.EXTENSION)
@@ -80,7 +80,7 @@ class CliIndicatorSerialization(threat_updates.ThreatUpdateSerialization):
             indicator_type = match.group(1)
             # Violate your warranty with class state! Not threadsafe!
             csv.field_size_limit(path.stat().st_size)  # dodge field size problems
-            with path.open("r", newline="") as f:
+            with path.open("r", encoding="utf-8", newline="") as f:
                 for row in csv.reader(f):
                     ret.append(
                         cls(
@@ -138,9 +138,7 @@ class HMASerialization(CliIndicatorSerialization):
         )
 
     @classmethod
-    def load(
-        cls, state_dir: pathlib.Path
-    ) -> t.List["threat_updates.ThreatUpdateSerialization"]:
+    def load(cls, state_dir: pathlib.Path) -> t.Iterable["HMASerialization"]:
         """Load this serialization from the state directory"""
         ret = []
         pattern = r"simple\.([^.]+)" + re.escape(Dataset.EXTENSION)
@@ -171,7 +169,7 @@ if __name__ == "__main__":
         indicator_id,
         SimpleDescriptorRollup(first_descriptor_id, added_on, labels),
     )
-    serdeser = HMASerialization.from_csv_row(ser.as_csv_row(), "HASH_PDQ")
+    serdeser = HMASerialization.from_csv_row(list(ser.as_csv_row()), "HASH_PDQ")
 
     if ser.as_csv_row() == serdeser.as_csv_row():
         print("Serialization worked correctly")
